@@ -567,7 +567,7 @@ STATIC int primloop(lprec *lp, MYBOOL primalfeasible, REAL primaloffset)
   int    i, j, k, colnr = 0, rownr = 0, lastnr = 0,
          candidatecount = 0, minitcount = 0, ok = TRUE;
   LREAL  theta = 0.0;
-  REAL   epsvalue, xviolated, cviolated = 0.0,
+  REAL   epsvalue, xviolated = 0.0, cviolated = 0.0,
          *prow = NULL, *pcol = NULL,
          *drow = lp->drow;
   int    *workINT = NULL,
@@ -1709,7 +1709,7 @@ lprec *make_lag(lprec *lpserver)
 
     /* First create and core variable data */
     set_sense(hlp, is_maxim(lpserver));
-    hlp->lag_bound = lpserver->bb_limitOF;
+    /*hlp->lag_bound = lpserver->bb_limitOF;*/
     for(i = 1; i <= lpserver->columns; i++) {
       set_mat(hlp, 0, i, get_mat(lpserver, 0, i));
       if(is_binary(lpserver, i))
@@ -1846,7 +1846,7 @@ STATIC int lag_solve(lprec *lp, REAL start_bound, int num_iter)
           LagFeas = FALSE;
       }
       /* Test for convergence and update */
-      if(Converged && (fabs(my_reldiff(hold , SubGrad[i])) > lp->lag_accept))
+      if(Converged && (fabs(my_reldiff(hold , SubGrad[i])) > /* lp->lag_accept */ DEF_LAGACCEPT))
         Converged = FALSE;
       SubGrad[i] = hold;
       SqrsumSubGrad += hold * hold;
@@ -1975,7 +1975,7 @@ STATIC int lag_solve(lprec *lp, REAL start_bound, int num_iter)
 
   /* Transfer solution values */
   if(AnyFeas) {
-    lp->lag_bound = my_chsign(is_maxim(lp), Zbest);
+    /*lp->lag_bound = my_chsign(is_maxim(lp), Zbest);*/
     for(i = 0; i <= lp->sum; i++)
       lp->solution[i] = BestFeasSol[i];
     transfer_solution(lp, TRUE);
